This will be replaced by the README.md in production.


Endpoints:

- [x] /color_families
- [X] /current_user
- [x] /fiber_attributes
- [x] /fiber_categories
- [x] /search
- [x] /yarn_weights
- [ ] /app
- [ ] /app
- [ ] /bundled_items
- [ ] /bundles
- [ ] /carts
- [X] /comments
- [ ] /deliveries
- [ ] /designers
- [ ] /drafts
- [ ] /favorites
- [ ] /fiber
- [ ] /fiber_attributes_groups
- [ ] /forum_posts
- [ ] /forums
- [ ] /friends
- [ ] /groups
- [ ] /in_store_sales
- [ ] /languages
- [ ] /library
- [ ] /messages
- [ ] /needles
- [ ] /packs
- [ ] /pages
- [ ] /pattern_attributes
- [ ] /pattern_categories
- [ ] /pattern_source_types
- [ ] /pattern_sources
- [ ] /patterns
- [x] /people
- [ ] /photos
- [ ] /product_attachments
- [ ] /products
- [ ] /projects
- [ ] /queue
- [ ] /saved_searches
- [ ] /shops
- [ ] /stash
- [ ] /stores
- [ ] /topics
- [ ] /upload
- [ ] /volumes
- [x] /yarn_attributes
- [x] /yarn_companies
- [ ] /yarns
